@@ -14,7 +14,7 @@ dat<-read.table(file, header=T, sep="\t", row.names=1)
 
 # Sanity checks
 if(p.value.column=="empty") {
-   stop("You haven't selected a phenodata column for p-value! Tool cannot be executed.")
+   stop("You haven't selected a data column for p-value! Tool cannot be executed.")
 }
 if(sum(grep("p.adjusted", colnames(dat)))==0) {
    stop("You don't have any P-value columns in the dataset! Please run some statistical test first.")
